summaryrefslogtreecommitdiff
path: root/resources/jquery.ui/jquery.ui.selectable.js
diff options
context:
space:
mode:
Diffstat (limited to 'resources/jquery.ui/jquery.ui.selectable.js')
-rw-r--r--resources/jquery.ui/jquery.ui.selectable.js8
1 files changed, 4 insertions, 4 deletions
diff --git a/resources/jquery.ui/jquery.ui.selectable.js b/resources/jquery.ui/jquery.ui.selectable.js
index d790ac0d..ac5bf046 100644
--- a/resources/jquery.ui/jquery.ui.selectable.js
+++ b/resources/jquery.ui/jquery.ui.selectable.js
@@ -1,7 +1,7 @@
/*
* jQuery UI Selectable 1.8.17
*
- * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
+ * Copyright 2012, AUTHORS.txt (http://jqueryui.com/about)
* Dual licensed under the MIT or GPL Version 2 licenses.
* http://jquery.org/license
*
@@ -261,7 +261,7 @@ $.widget("ui.selectable", $.ui.mouse, {
});
$.extend($.ui.selectable, {
- version: "1.8.17"
+ version: "1.8.23"
});
})(jQuery);
@@ -1,7 +1,7 @@
-/*
- * jQuery UI Selectable 1.8.17
+/*!
+ * jQuery UI Selectable 1.8.23
*